@@ -1,6 +1,6 @@
 from nonebot.adapters import Bot
 
-from . import adapter_api as adapter_api
+from . import adapter_api
 from .api import API as API
 from .api import api_registry
 from .user_const_var import default_context as default_context
@@ -12,3 +12,6 @@ def get_api_class(bot: Bot) -> type[API]:
         if isinstance(bot.adapter, cls):
             return api
     return API
+
+
+adapter_api.load()
