@@ -1,13 +1,14 @@
 from io import BytesIO
+from typing import NoReturn
 
 import PIL.Image
-from nonebot import on_startswith
+from nonebot import on_message
 from nonebot.adapters import Bot, Event
 from nonebot_plugin_alconna.uniseg import UniMessage, image_fetch
 
-from .depends import AllowExeCode, CodeContext, EventImage
+from .depends import AllowExeCode, CodeContext, EventImage, startswith
 
-matcher = on_startswith("getimg", permission=AllowExeCode)
+matcher = on_message(startswith("getimg"), permission=AllowExeCode)
 
 
 @matcher.handle()
@@ -16,8 +17,10 @@ async def handle_getimg(
     event: Event,
     ctx: CodeContext,
     image: EventImage,
-):
-    varname = event.get_message().extract_plain_text().removeprefix("getimg").strip()
+) -> NoReturn:
+    varname = (
+        event.get_message().extract_plain_text().strip().removeprefix("getimg").strip()
+    )
     if (varname := varname or "img") and not varname.isidentifier():
         await UniMessage(f"{varname} 不是一个合法的 Python 标识符").finish()
 
