@@ -1,26 +1,23 @@
+# ruff: noqa: S101
+
 import asyncio
 
 import pytest
 from nonebot.adapters.onebot.v11 import Message
 from nonebug import App
 
-from tests.fake import (
-    ensure_context,
-    fake_user_id,
-    fake_v11_bot,
-    fake_v11_event_session,
-)
+from tests.fake import ensure_context, fake_v11_bot, fake_v11_event_session
 
 
 @pytest.mark.asyncio
-async def test_lock(app: App):
+async def test_lock(app: App) -> None:
     from nonebot_plugin_exe_code.context import Context
 
     async with app.test_api() as ctx:
         bot = fake_v11_bot(ctx)
         event, session = fake_v11_event_session(bot)
 
-        async def _test(delay: float, code: str):
+        async def _test(delay: float, code: str) -> None:
             await asyncio.sleep(delay)
             await Context.execute(bot, session, code)
 
@@ -35,7 +32,7 @@ async def test_lock(app: App):
 
 
 @pytest.mark.asyncio
-async def test_cancel(app: App):
+async def test_cancel(app: App) -> None:
     from nonebot_plugin_exe_code.context import Context
 
     async with app.test_api() as ctx:
@@ -43,11 +40,11 @@ async def test_cancel(app: App):
         event, session = fake_v11_event_session(bot)
         result = False
 
-        async def _test1():
+        async def _test1() -> None:
             with pytest.raises(asyncio.CancelledError):
                 await Context.execute(bot, session, "await sleep(1); print(1)")
 
-        async def _test2():
+        async def _test2() -> None:
             nonlocal result
             await asyncio.sleep(0.01)
             result = Context.get_context(session).cancel()
@@ -57,12 +54,15 @@ async def test_cancel(app: App):
         assert result
 
 
-def test_context_variable():
+async def test_context_variable(app: App) -> None:
     from nonebot_plugin_alconna.uniseg import Image, UniMessage
 
     from nonebot_plugin_exe_code.context import Context
 
-    context = Context.get_context(str(fake_user_id()))
+    async with app.test_api() as ctx:
+        bot = fake_v11_bot(ctx)
+        _, session = fake_v11_event_session(bot)
+        context = Context.get_context(session)
 
     key, val = "aaa", 111
     context.set_value(key, val)
